//==============================================================================================
//
//	Windows Interface Construction Set
//	Version 1.00
//
//	TIMEEDT.CPP - Time Edit Field Source File
//	Copyright  1993 by Microdyne Development Technologies.
//	All rights reserved.
//==============================================================================================

#include <owl.h>
#include <timeedt.h>

TTimeEdit::TTimeEdit (PTWindowsObject AParent, int ResourceId, PTModule AModule)
	: TEdit (AParent, ResourceId, 0, AModule)
{
}

TTimeEdit::~TTimeEdit ()
{
}

void TTimeEdit::WMCommand (RTMessage Msg)
{
	DefWndProc(Msg);
}

void TTimeEdit::SetupWindow ()
{
	TEdit::SetupWindow();
}

int TTimeEdit::GetLineLength()
{
	TMessage	msg;

	msg.Receiver = HWindow;
	msg.Message  = EM_LINELENGTH;
	msg.WParam   = 0;
	msg.LParam   = 0L;
	msg.Result   = 0L;

	DefWndProc (msg);

	return (int) msg.Result;
}

BOOL TTimeEdit::GetLine(LPSTR ATextString, int StrSize)
{
	TMessage	msg;
    int			BytesCopied;
	BOOL		Success;

	if ( StrSize <= 0 )
    	return FALSE;

	if ( (StrSize >= GetLineLength() + 1) )
    	Success = TRUE;
	else
    	Success = FALSE;

	if ( StrSize == 1 )
	{
    	ATextString[0] = '\0';
		return Success;
	}

	msg.Receiver = HWindow;
	msg.Message  = EM_GETLINE;
	msg.WParam   = 0;
	msg.LParam   = (LPARAM) ATextString;
	msg.Result   = 0L;

	DefWndProc (msg);

	BytesCopied = (int) msg.Result;

	if ( BytesCopied != 0 )
	{
		ATextString[BytesCopied] = '\0'; // Windows returns non-null terminated string
		return Success;
	}

	return FALSE;
}

void TTimeEdit::GetTime(long & lSeconds, Rint iHour, Rint iMinute, Rint iSecond)
{
	TMessage	msg;
    WORD		wTime[3];

	msg.Receiver = HWindow;
	msg.Message  = TEM_GETTIME;
	msg.WParam   = 0;
	msg.LParam   = (LPARAM) wTime;
	msg.Result   = 0L;

	DefWndProc (msg);

	iHour   = wTime[0];
	iMinute = wTime[1];
	iSecond = wTime[2];
    lSeconds = (long) iSecond + 60 * (long) iMinute + 3600 * (long) iHour ;
}

void TTimeEdit::SetTime(Rint iHour, Rint iMinute, Rint iSecond)
{
	TMessage	msg;
    WORD		wTime[3];

	wTime[0] = iHour;
	wTime[1] = iMinute;
	wTime[2] = iSecond;

	msg.Receiver = HWindow;
	msg.Message  = TEM_SETTIME;
	msg.WParam   = 0;
	msg.LParam   = (LPARAM) wTime;
	msg.Result   = 0L;

	DefWndProc (msg);
}

void TTimeEdit::GetHour(Rint iHour)
{
	TMessage	msg;

	msg.Receiver = HWindow;
	msg.Message  = TEM_GETHOUR;
	msg.WParam   = 0;
	msg.LParam   = 0L;
	msg.Result   = 0L;

	DefWndProc (msg);

	iHour = msg.Result;
}

void TTimeEdit::GetMinute(Rint iMinute)
{
	TMessage	msg;

	msg.Receiver = HWindow;
	msg.Message  = TEM_GETMINUTE;
	msg.WParam   = 0;
	msg.LParam   = 0L;
	msg.Result   = 0L;

	DefWndProc (msg);

	iMinute = msg.Result;
}

void TTimeEdit::GetSecond(Rint iSecond)
{
	TMessage	msg;

	msg.Receiver = HWindow;
	msg.Message  = TEM_GETSECOND;
	msg.WParam   = 0;
	msg.LParam   = 0L;
	msg.Result   = 0L;

	DefWndProc (msg);

	iSecond = msg.Result;
}

void TTimeEdit::GetEditParams (LPDECPARMS lpep)
{
	TMessage	msg;

	msg.Receiver = HWindow;
	msg.Message  = DEM_GETEDITPARAMS;
	msg.WParam   = 0;
	msg.LParam   = (LPARAM) lpep;
	msg.Result   = 0L;

	DefWndProc (msg);
}

void TTimeEdit::SetEditParams (LPDECPARMS lpep)
{
	TMessage	msg;

	msg.Receiver = HWindow;
	msg.Message  = DEM_SETEDITPARAMS;
	msg.WParam   = 0;
	msg.LParam   = (LPARAM) lpep;
	msg.Result   = 0L;

	DefWndProc (msg);
}
